@@ -34,6 +34,11 @@ DEFINE_TEST(test_option_exclude_vcs)
 DEFINE_TEST(test_option_fflags)
 DEFINE_TEST(test_option_gid_gname)
 DEFINE_TEST(test_option_grzip)
+DEFINE_TEST(test_option_ignore_zeros_mode_t)
+DEFINE_TEST(test_option_ignore_zeros_mode_x)
+DEFINE_TEST(test_option_ignore_zeros_mode_c)
+DEFINE_TEST(test_option_ignore_zeros_mode_r)
+DEFINE_TEST(test_option_ignore_zeros_mode_u)
 DEFINE_TEST(test_option_j)
 DEFINE_TEST(test_option_k)
 DEFINE_TEST(test_option_keep_newer_files)
